@@ -1,10 +1,10 @@
 package Net::DNS::RR::DNSKEY;
 
 #
-# $Id: DNSKEY.pm 1456 2016-02-17 13:34:00Z willem $
+# $Id: DNSKEY.pm 1468 2016-03-21 13:11:35Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1456 $)[1];
+$VERSION = (qw$LastChangedRevision: 1468 $)[1];
 
 
 use strict;
@@ -21,7 +21,7 @@ use integer;
 
 use Carp;
 
-eval 'require MIME::Base64';
+use constant BASE64 => defined eval 'require MIME::Base64';
 
 #
 # source: http://www.iana.org/assignments/dns-sec-alg-numbers
@@ -88,6 +88,7 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	return '' unless defined $self->{keybin};
+	return &Net::DNS::RR::_format_rdata($self) unless BASE64;
 	pack 'n C2 a*', $self->flags, $self->protocol, $self->algorithm, $self->{keybin};
 }
 
