@@ -1,10 +1,10 @@
 package Net::DNS::RR::TSIG;
 
 #
-# $Id: TSIG.pm 1456 2016-02-17 13:34:00Z willem $
+# $Id: TSIG.pm 1475 2016-04-15 09:46:40Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1456 $)[1];
+$VERSION = (qw$LastChangedRevision: 1475 $)[1];
 
 
 use strict;
@@ -33,6 +33,7 @@ use constant ANY  => classbyname qw(ANY);
 use constant TSIG => typebyname qw(TSIG);
 
 {
+	# source: http://www.iana.org/assignments/tsig-algorithm-names
 	my @algbyname = (
 		'HMAC-MD5.SIG-ALG.REG.INT' => 157,
 		'HMAC-SHA1'		   => 161,
@@ -347,7 +348,7 @@ sub sig_data {
 sub create {
 	my $class = shift;
 	my $karg  = shift;
-	croak 'argument missing or undefined' unless defined $karg;
+	croak 'argument undefined' unless defined $karg;
 
 	if ( ref($karg) ) {
 		if ( $karg->isa('Net::DNS::Packet') ) {
@@ -445,24 +446,19 @@ sub verify {
 		if ( $arg->isa('Net::DNS::Packet') ) {
 			my $request = $arg->sigrr;		# request TSIG
 			my $rqstkey = lc( join '+', $request->name, $request->algorithm );
-			unless ( $signerkey eq $rqstkey ) {
-				$self->error(17);
-				return;
-			}
+			$self->error(17) unless $signerkey eq $rqstkey;
 			$self->request_macbin( $request->macbin );
 
 		} elsif ( $arg->isa(__PACKAGE__) ) {
 			my $priorkey = lc( join '+', $arg->name, $arg->algorithm );
-			unless ( $signerkey eq $priorkey ) {
-				$self->error(17);
-				return;
-			}
+			$self->error(17) unless $signerkey eq $priorkey;
 			$self->prior_macbin( $arg->macbin );
 
 		} else {
 			croak 'Usage: $tsig->verify( $reply, $query )';
 		}
 	}
+	return if $self->{error};
 
 	my $sigdata = $self->sig_data($data);			# form data to be verified
 	my $tsigmac = $self->_mac_function($sigdata);
@@ -471,14 +467,10 @@ sub verify {
 	my $macbin = $self->macbin;
 	my $maclen = length $macbin;
 	my $minlen = length($tsigmac) >> 1;			# per RFC4635, 3.1
-	if ( $maclen < $minlen or $maclen < 10 or $maclen > length $tsigmac ) {
-		$self->error(1);
-		return;
-	}
+	$self->error(16) unless $macbin eq substr $tsigmac, 0, $maclen;
+	$self->error(1) if $maclen < $minlen or $maclen < 10 or $maclen > length $tsigmac;
 
-	return $tsig if $macbin eq substr $tsigmac, 0, $maclen;
-	$self->error(16);
-	return;
+	return $self->{error} ? undef : $tsig;
 }
 
 sub vrfyerrstr {
@@ -850,4 +842,6 @@ DEALINGS IN THE SOFTWARE.
 
 L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC2845, RFC4635
 
+L<TSIG Algorithm Names|http://www.iana.org/assignments/tsig-algorithm-names>
+
 =cut
